pub fn stream_decode(data: &[u8]) -> Result<StreamMessage, Error>Expand description
Decode a single JSON stream line into a StreamMessage.
Errors
Returns an error if the JSON is malformed or the op field is missing/unknown.
pub fn stream_decode(data: &[u8]) -> Result<StreamMessage, Error>Decode a single JSON stream line into a StreamMessage.
Returns an error if the JSON is malformed or the op field is missing/unknown.